==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/AdresatSprawozdania.java <==
package pl.topteam.dps.model.main_gen;

import pl.topteam.dps.enums.RodzajSprawozdania;
import pl.topteam.dps.generic.GenericDPSObject;

public abstract class AdresatSprawozdania extends GenericDPSObject {
    /**
     * ADRESAT_SPRAWOZDANIA.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * ADRESAT_SPRAWOZDANIA.ADRES_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long adresId;

    /**
     * ADRESAT_SPRAWOZDANIA.KOD_KESO
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String kodKeso;

    /**
     * ADRESAT_SPRAWOZDANIA.NAZWA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String nazwa;

    /**
     * ADRESAT_SPRAWOZDANIA.RODZAJ_SPRAWOZDANIA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private RodzajSprawozdania rodzajSprawozdania;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return ADRESAT_SPRAWOZDANIA.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * ADRESAT_SPRAWOZDANIA.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return ADRESAT_SPRAWOZDANIA.ADRES_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getAdresId() {
        return adresId;
    }

    /**
     * ADRESAT_SPRAWOZDANIA.ADRES_ID
     *
     * @param adresId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setAdresId(Long adresId) {
        this.adresId = adresId;
    }

    /**
     * @return ADRESAT_SPRAWOZDANIA.KOD_KESO
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getKodKeso() {
        return kodKeso;
    }

    /**
     * ADRESAT_SPRAWOZDANIA.KOD_KESO
     *
     * @param kodKeso
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setKodKeso(String kodKeso) {
        this.kodKeso = kodKeso == null ? null : kodKeso.trim();
    }

    /**
     * @return ADRESAT_SPRAWOZDANIA.NAZWA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getNazwa() {
        return nazwa;
    }

    /**
     * ADRESAT_SPRAWOZDANIA.NAZWA
     *
     * @param nazwa
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setNazwa(String nazwa) {
        this.nazwa = nazwa == null ? null : nazwa.trim();
    }

    /**
     * @return ADRESAT_SPRAWOZDANIA.RODZAJ_SPRAWOZDANIA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public RodzajSprawozdania getRodzajSprawozdania() {
        return rodzajSprawozdania;
    }

    /**
     * ADRESAT_SPRAWOZDANIA.RODZAJ_SPRAWOZDANIA
     *
     * @param rodzajSprawozdania
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setRodzajSprawozdania(RodzajSprawozdania rodzajSprawozdania) {
        this.rodzajSprawozdania = rodzajSprawozdania;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        AdresatSprawozdania other = (AdresatSprawozdania) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getAdresId() == null ? other.getAdresId() == null : this.getAdresId().equals(other.getAdresId()))
            && (this.getKodKeso() == null ? other.getKodKeso() == null : this.getKodKeso().equals(other.getKodKeso()))
            && (this.getNazwa() == null ? other.getNazwa() == null : this.getNazwa().equals(other.getNazwa()))
            && (this.getRodzajSprawozdania() == null ? other.getRodzajSprawozdania() == null : this.getRodzajSprawozdania().equals(other.getRodzajSprawozdania()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getAdresId() == null) ? 0 : getAdresId().hashCode());
        result = prime * result + ((getKodKeso() == null) ? 0 : getKodKeso().hashCode());
        result = prime * result + ((getNazwa() == null) ? 0 : getNazwa().hashCode());
        result = prime * result + ((getRodzajSprawozdania() == null) ? 0 : getRodzajSprawozdania().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", adresId=").append(adresId);
        sb.append(", kodKeso=").append(kodKeso);
        sb.append(", nazwa=").append(nazwa);
        sb.append(", rodzajSprawozdania=").append(rodzajSprawozdania);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/AdresatSprawozdania.java <==
package pl.topteam.dps.model.main_gen;

import pl.topteam.dps.enums.RodzajSprawozdania;
import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class AdresatSprawozdania extends GenericDPSObject {
    /**
     * ADRESAT_SPRAWOZDANIA.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * ADRESAT_SPRAWOZDANIA.ADRES_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long adresId;

    /**
     * ADRESAT_SPRAWOZDANIA.KOD_KESO
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String kodKeso;

    /**
     * ADRESAT_SPRAWOZDANIA.NAZWA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String nazwa;

    /**
     * ADRESAT_SPRAWOZDANIA.RODZAJ_SPRAWOZDANIA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private RodzajSprawozdania rodzajSprawozdania;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return ADRESAT_SPRAWOZDANIA.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * ADRESAT_SPRAWOZDANIA.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return ADRESAT_SPRAWOZDANIA.ADRES_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getAdresId() {
        return adresId;
    }

    /**
     * ADRESAT_SPRAWOZDANIA.ADRES_ID
     *
     * @param adresId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setAdresId(Long adresId) {
        this.adresId = adresId;
    }

    /**
     * @return ADRESAT_SPRAWOZDANIA.KOD_KESO
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getKodKeso() {
        return kodKeso;
    }

    /**
     * ADRESAT_SPRAWOZDANIA.KOD_KESO
     *
     * @param kodKeso
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setKodKeso(String kodKeso) {
        this.kodKeso = kodKeso == null ? null : kodKeso.trim();
    }

    /**
     * @return ADRESAT_SPRAWOZDANIA.NAZWA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getNazwa() {
        return nazwa;
    }

    /**
     * ADRESAT_SPRAWOZDANIA.NAZWA
     *
     * @param nazwa
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setNazwa(String nazwa) {
        this.nazwa = nazwa == null ? null : nazwa.trim();
    }

    /**
     * @return ADRESAT_SPRAWOZDANIA.RODZAJ_SPRAWOZDANIA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public RodzajSprawozdania getRodzajSprawozdania() {
        return rodzajSprawozdania;
    }

    /**
     * ADRESAT_SPRAWOZDANIA.RODZAJ_SPRAWOZDANIA
     *
     * @param rodzajSprawozdania
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setRodzajSprawozdania(RodzajSprawozdania rodzajSprawozdania) {
        this.rodzajSprawozdania = rodzajSprawozdania;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        AdresatSprawozdania other = (AdresatSprawozdania) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getAdresId() == null ? other.getAdresId() == null : this.getAdresId().equals(other.getAdresId()))
            && (this.getKodKeso() == null ? other.getKodKeso() == null : this.getKodKeso().equals(other.getKodKeso()))
            && (this.getNazwa() == null ? other.getNazwa() == null : this.getNazwa().equals(other.getNazwa()))
            && (this.getRodzajSprawozdania() == null ? other.getRodzajSprawozdania() == null : this.getRodzajSprawozdania().equals(other.getRodzajSprawozdania()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getAdresId() == null) ? 0 : getAdresId().hashCode());
        result = prime * result + ((getKodKeso() == null) ? 0 : getKodKeso().hashCode());
        result = prime * result + ((getNazwa() == null) ? 0 : getNazwa().hashCode());
        result = prime * result + ((getRodzajSprawozdania() == null) ? 0 : getRodzajSprawozdania().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", adresId=").append(adresId);
        sb.append(", kodKeso=").append(kodKeso);
        sb.append(", nazwa=").append(nazwa);
        sb.append(", rodzajSprawozdania=").append(rodzajSprawozdania);
        sb.append("]");
        return sb.toString();
    }
}
